==> jndn-without-protobuf-0.7.1-sources.jar: net/named_data/jndn/Sha256WithRsaSignature.java <==
/**
 * Copyright (C) 2013-2015 Regents of the University of California.
 * @author: Jeff Thompson <jefft0@remap.ucla.edu>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * A copy of the GNU Lesser General Public License is in the file COPYING.
 */

package net.named_data.jndn;

import net.named_data.jndn.encoding.WireFormat;
import net.named_data.jndn.util.Blob;
import net.named_data.jndn.util.ChangeCounter;

/**
 * A Sha256WithRsaSignature extends Signature and holds the signature bits and
 * other info representing a
 * SHA256-with-RSA signature in a data packet.
 */
public class Sha256WithRsaSignature extends Signature {
  /**
   * Create a new Sha256WithRsaSignature with default values.
   */
  public Sha256WithRsaSignature()
  {
  }

  /**
   * Create a new Sha256WithRsaSignature with a copy of the fields in the given
   * signature object.
   * @param signature The signature object to copy.
   */
  public Sha256WithRsaSignature(Sha256WithRsaSignature signature)
  {
    digestAlgorithm_ = signature.digestAlgorithm_;
    witness_ = signature.witness_;
    signature_ = signature.signature_;
    publisherPublicKeyDigest_.set
      (new PublisherPublicKeyDigest(signature.getPublisherPublicKeyDigest()));
    keyLocator_.set(new KeyLocator(signature.getKeyLocator()));
  }

  /**
   * Return a new Signature which is a deep copy of this signature.
   * @return A new Sha256WithRsaSignature.
   * @throws CloneNotSupportedException
   */
  public Object clone() throws CloneNotSupportedException
  {
    return new Sha256WithRsaSignature(this);
  }

  /**
   * @deprecated This is for the NDNx wire format which is deprecated.
   */
  public final Blob
  getDigestAlgorithm()
  {
    if (!WireFormat.ENABLE_NDNX)
      throw new Error
        ("The Digest Algorithm is for the NDNx wire format and is deprecated. To enable while you upgrade your code to use NDN-TLV, set WireFormat.ENABLE_NDNX = true");

    return digestAlgorithm_;
  }

  /**
   * @deprecated This is for the NDNx wire format which is deprecated.
   */
  public final Blob
  getWitness()
  {
    if (!WireFormat.ENABLE_NDNX)
      throw new Error
        ("The Witness is for the NDNx wire format and is deprecated. To enable while you upgrade your code to use NDN-TLV, set WireFormat.ENABLE_NDNX = true");

    return witness_;
  }

  /**
   * Get the signature bytes.
   * @return The signature bytes. If not specified, the value isNull().
   */
  public final Blob
  getSignature() { return signature_; }

  /**
   * @deprecated The Signature publisherPublicKeyDigest is deprecated. If you
   * need a publisher public key digest, set the keyLocator keyLocatorType to
   * KEY_LOCATOR_DIGEST and set its key data to the digest.
   */
  public final PublisherPublicKeyDigest
  getPublisherPublicKeyDigest()
  {
    return (PublisherPublicKeyDigest)publisherPublicKeyDigest_.get();
  }

  public final KeyLocator
  getKeyLocator() { return (KeyLocator)keyLocator_.get(); }

  /**
   * @deprecated This is for the NDNx wire format which is deprecated.
   */
  public final void
  setDigestAlgorithm(Blob digestAlgorithm)
  {
    if (!WireFormat.ENABLE_NDNX)
      throw new Error
        ("The Digest Algorithm is for the NDNx wire format and is deprecated. To enable while you upgrade your code to use NDN-TLV, set WireFormat.ENABLE_NDNX = true");

    digestAlgorithm_ = (digestAlgorithm == null ? new Blob() : digestAlgorithm);
    ++changeCount_;
  }

  /**
   * @deprecated This is for the NDNx wire format which is deprecated.
   */
  public final void
  setWitness(Blob witness)
  {
    if (!WireFormat.ENABLE_NDNX)
      throw new Error
        ("The Witness is for the NDNx wire format and is deprecated. To enable while you upgrade your code to use NDN-TLV, set WireFormat.ENABLE_NDNX = true");

    witness_ = (witness == null ? new Blob() : witness);
    ++changeCount_;
  }

  /**
   * Set the signature bytes to the given value.
   * @param signature A Blob with the signature bytes.
   */
  public final void
  setSignature(Blob signature)
  {
    signature_ = (signature == null ? new Blob() : signature);
    ++changeCount_;
  }

  /**
   * @deprecated The Signature publisherPublicKeyDigest is deprecated. If you
   * need a publisher public key digest, set the keyLocator keyLocatorType to
   * KEY_LOCATOR_DIGEST and set its key data to the digest.
   */
  public final void
  setPublisherPublicKeyDigest(PublisherPublicKeyDigest publisherPublicKeyDigest)
  {
    publisherPublicKeyDigest_.set
      (publisherPublicKeyDigest == null ? new PublisherPublicKeyDigest()
      : new PublisherPublicKeyDigest(publisherPublicKeyDigest));
    ++changeCount_;
  }

  public final void
  setKeyLocator(KeyLocator keyLocator)
  {
    keyLocator_.set
      ((keyLocator == null ? new KeyLocator() : new KeyLocator(keyLocator)));
    ++changeCount_;
  }

  /**
   * Get the change count, which is incremented each time this object
   * (or a child object) is changed.
   * @return The change count.
   */
  public final long
  getChangeCount()
  {
    // Make sure each of the checkChanged is called.
    boolean changed = publisherPublicKeyDigest_.checkChanged();
    changed = keyLocator_.checkChanged() || changed;
    if (changed)
      // A child object has changed, so update the change count.
      ++changeCount_;

    return changeCount_;
  }

  private Blob digestAlgorithm_ = new Blob(); /**< if empty, the default is
                                             2.16.840.1.101.3.4.2.1 (sha-256) */
  private Blob witness_ = new Blob();
  private Blob signature_ = new Blob();
  private final ChangeCounter publisherPublicKeyDigest_ =
    new ChangeCounter(new PublisherPublicKeyDigest());
  private final ChangeCounter keyLocator_ = new ChangeCounter(new KeyLocator());
  private long changeCount_ = 0;
}

==> jndn-without-protobuf-0.13-sources.jar: net/named_data/jndn/Sha256WithRsaSignature.java <==
/**
 * Copyright (C) 2013-2016 Regents of the University of California.
 * @author: Jeff Thompson <jefft0@remap.ucla.edu>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * A copy of the GNU Lesser General Public License is in the file COPYING.
 */

package net.named_data.jndn;

import net.named_data.jndn.encoding.WireFormat;
import net.named_data.jndn.util.Blob;
import net.named_data.jndn.util.ChangeCounter;

/**
 * A Sha256WithRsaSignature extends Signature and holds the signature bits and
 * other info representing a
 * SHA256-with-RSA signature in a data packet.
 */
public class Sha256WithRsaSignature extends Signature {
  /**
   * Create a new Sha256WithRsaSignature with default values.
   */
  public Sha256WithRsaSignature()
  {
  }

  /**
   * Create a new Sha256WithRsaSignature with a copy of the fields in the given
   * signature object.
   * @param signature The signature object to copy.
   */
  public Sha256WithRsaSignature(Sha256WithRsaSignature signature)
  {
    signature_ = signature.signature_;
    keyLocator_.set(new KeyLocator(signature.getKeyLocator()));
  }

  /**
   * Return a new Signature which is a deep copy of this signature.
   * @return A new Sha256WithRsaSignature.
   * @throws CloneNotSupportedException
   */
  public Object clone() throws CloneNotSupportedException
  {
    return new Sha256WithRsaSignature(this);
  }

  /**
   * Get the signature bytes.
   * @return The signature bytes. If not specified, the value isNull().
   */
  public final Blob
  getSignature() { return signature_; }

  public final KeyLocator
  getKeyLocator() { return (KeyLocator)keyLocator_.get(); }

  /**
   * Set the signature bytes to the given value.
   * @param signature A Blob with the signature bytes.
   */
  public final void
  setSignature(Blob signature)
  {
    signature_ = (signature == null ? new Blob() : signature);
    ++changeCount_;
  }

  public final void
  setKeyLocator(KeyLocator keyLocator)
  {
    keyLocator_.set
      ((keyLocator == null ? new KeyLocator() : new KeyLocator(keyLocator)));
    ++changeCount_;
  }

  /**
   * Get the change count, which is incremented each time this object
   * (or a child object) is changed.
   * @return The change count.
   */
  public final long
  getChangeCount()
  {
    // Make sure each of the checkChanged is called.
    boolean changed = keyLocator_.checkChanged();
    if (changed)
      // A child object has changed, so update the change count.
      ++changeCount_;

    return changeCount_;
  }

  private Blob signature_ = new Blob();
  private final ChangeCounter keyLocator_ = new ChangeCounter(new KeyLocator());
  private long changeCount_ = 0;
}
